@@ -2,7 +2,9 @@ import numpy as np
 from .non_dimension import toone
 
 
-def topsis(data_origin: np.ndarray, weights: list[int | float] | np.ndarray) -> np.matrix:
+def topsis(
+    data_origin: np.ndarray, weights: list[int | float] | np.ndarray
+) -> np.matrix:
     """计算优劣解距离法得分矩阵，weights为权重矩阵。
 
     Args:
@@ -28,7 +30,7 @@ def topsis(data_origin: np.ndarray, weights: list[int | float] | np.ndarray) ->
 
     d1: np.ndarray = np.sqrt(empty_matrix1.sum(axis=1))
     d2: np.ndarray = np.sqrt(empty_matrix2.sum(axis=1))
-    result: np.ndarray = (d2/(d1+d2))
+    result: np.ndarray = d2 / (d1 + d2)
     return np.mat(result.reshape(result.shape[0], 1))
 
 
@@ -49,10 +51,12 @@ def rsr(data_origin: np.ndarray, weights: list[int | float] | np.ndarray) -> np.
     for q in range(n):
         compare_list: np.ndarray = np.sort(data[:, q])
         rsr_matrix[:, q] = np.searchsorted(compare_list, data[:, q])
-    return rsr_matrix * np.mat(weights).T / m   # type: ignore
+    return rsr_matrix * np.mat(weights).T / m  # type: ignore
 
 
-def ni_rsr(data_origin: np.ndarray, weights: list[int | float] | np.ndarray) -> np.matrix:
+def ni_rsr(
+    data_origin: np.ndarray, weights: list[int | float] | np.ndarray
+) -> np.matrix:
     """计算非整次秩和比得分矩阵，weights为权重矩阵。
 
     Args:
@@ -69,6 +73,5 @@ def ni_rsr(data_origin: np.ndarray, weights: list[int | float] | np.ndarray) ->
     for q in range(n):
         max_v = data[:, q].max()
         min_v = data[:, q].min()
-        rsr_matrix[:, q] = 1 + \
-            ((m - 1) * (data[:, q] - min_v) / (max_v - min_v))
+        rsr_matrix[:, q] = 1 + ((m - 1) * (data[:, q] - min_v) / (max_v - min_v))
     return rsr_matrix * np.mat(weights).T / m  # type: ignore
